udev support isn't actually in the server yet but it will announce itself as
server/udev in the source. If so, hook onto it in the same manner as onto
HAL.

This allows for easier testing with a udev-enabled development server (which
is already in Debian).

Signed-off-by: Peter Hutterer <[email protected]>
---
 src/wcmValidateDevice.c |    7 +++----
 1 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/src/wcmValidateDevice.c b/src/wcmValidateDevice.c
index 86156b7..ed02507 100644
--- a/src/wcmValidateDevice.c
+++ b/src/wcmValidateDevice.c
@@ -351,8 +351,8 @@ void wcmHotplugOthers(LocalDevicePtr local, unsigned long* 
keys)
 /**
  * Return 1 if the device needs auto-hotplugging from within the driver.
  * This is the case if we don't get passed a "type" option (invalid in
  * xorg.conf configurations) and we come from HAL or whatever future config
  * backend.
  *
  * This changes the source to _driver/wacom, all auto-hotplugged devices
  * will have the same source.
@@ -366,8 +366,7 @@ int wcmNeedAutoHotplug(LocalDevicePtr local, const char 
**type,
        if (*type) /* type specified, don't hotplug */
                return 0;
 
-       /* Only supporting HAL so far */
-       if (strcmp(source, "server/hal"))
+       if (strcmp(source, "server/hal") && strcmp(source, "server/udev"))
                return 0;
 
        /* no type specified, so we need to pick the first one applicable
@@ -351,8 +351,8 @@ void wcmHotplugOthers(LocalDevicePtr local, unsigned long* 
  * Return 1 if the device needs auto-hotplugging from within the driver.
  * This is the case if we don't get passed a "type" option (invalid in
- * xorg.conf configurations) and we come from HAL or whatever future config
- * backend.
+ * xorg.conf configurations) and we come from HAL, udev or whatever future
+ * config backend.
  *
  * This changes the source to _driver/wacom, all auto-hotplugged devices
-- 
1.6.5.2


------------------------------------------------------------------------------
Return on Information:
Google Enterprise Search pays you back
Get the facts.
http://p.sf.net/sfu/google-dev2dev
_______________________________________________
Linuxwacom-devel mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/linuxwacom-devel

Reply via email to